@@ -18,6 +18,7 @@ TIME_UNITS_SET = ['daily', 'weekly', 'monthly', 'quarterly', 'semi-annually', 'y
 
 KSH_SHELLS = ['/bin/sh', '/bin/dash', '/bin/ksh', '/bin/bash', '/usr/bin/zsh']
 REBOOT_FILE = '/run/crond.reboot'
+RANDOMIZED_DELAY = @randomized_delay@
 
 SELF = os.path.basename(sys.argv[0])
 
@@ -428,7 +429,11 @@ def generate_timer_unit(job, seq):
         f.write('Unit=%s.service\n' % unit_name)
         if schedule: f.write('OnCalendar=%s\n' % schedule)
         else:        f.write('OnBootSec=%sm\n' % delay)
-        if job['a'] != 1: f.write('AccuracySec=%sm\n' % job['a'])
+        if job['a'] != 1:
+            if RANDOMIZED_DELAY:
+                f.write('RandomizedDelaySec=%sm\n' % job['a'])
+            else:
+                f.write('AccuracySec=%sm\n' % job['a'])
         if @persistent@ and persistent: f.write('Persistent=true\n')
 
     try:
@@ -450,16 +455,21 @@ def generate_timer_unit(job, seq):
             f.write('OnFailure=cron-failure@%i.service\n')
         if job['u'] != 'root' or job['f'] == '@statedir@/root':
             f.write('Requires=systemd-user-sessions.service\n')
-            if home: f.write('RequiresMountsFor=%s\n' % home)
+            if home:
+                f.write('RequiresMountsFor=%s\n' % home)
 
         f.write('\n[Service]\n')
         f.write('Type=oneshot\n')
         f.write('IgnoreSIGPIPE=false\n')
-        if schedule and delay: f.write('ExecStartPre=-@libdir@/@package@/boot_delay %s\n' % delay)
+        if schedule and delay:
+             f.write('ExecStartPre=-@libdir@/@package@/boot_delay %s\n' % delay)
         f.write('ExecStart=%s\n' % command)
-        if job['e']: f.write('Environment=%s\n' % job['e'])
-        if job['u'] != 'root': f.write('User=%s\n' % job['u'])
-        if standardoutput: f.write('StandardOutput=%s\n' % standardoutput)
+        if job['e']:
+             f.write('Environment=%s\n' % job['e'])
+        if job['u'] != 'root':
+             f.write('User=%s\n' % job['u'])
+        if standardoutput:
+             f.write('StandardOutput=%s\n' % standardoutput)
         if job['Z']:
              f.write('CPUSchedulingPolicy=idle\n')
              f.write('IOSchedulingClass=idle\n')
@@ -558,7 +568,7 @@ def main():
 
             f.write('\n[Service]\n')
             f.write('Type=oneshot\n')
-            f.write('ExecStart=/bin/sh -c "@bindir@/systemctl daemon-reload ; @bindir@/systemctl try-restart cron.target"\n')
+            f.write('ExecStart=/bin/sh -c "systemctl daemon-reload ; systemctl try-restart cron.target"\n')
 
         MULTIUSER_DIR = os.path.join(TARGET_DIR, 'multi-user.target.wants')
 
